/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file linkgraphjob_base.h Some typedefs for component handlers. */

#ifndef LINKGRAPHJOB_BASE_H
#define LINKGRAPHJOB_BASE_H

#include "linkgraph.h"
#include "linkgraphjob.h"
#include "linkgraphschedule.h"

typedef LinkGraphJob::NodeAnnotation Node;
typedef LinkGraphJob::EdgeAnnotation Edge;

#endif /* LINKGRAPHJOB_BASE_H */
